@@ -1,6 +1,19 @@
-# file MASS/logtrans.q
+# file MASS/R/logtrans.R
 # copyright (C) 1994-9 W. N. Venables and B. D. Ripley
 #
+#  This program is free software; you can redistribute it and/or modify
+#  it under the terms of the GNU General Public License as published by
+#  the Free Software Foundation; either version 2 or 3 of the License
+#  (at your option).
+#
+#  This program is distributed in the hope that it will be useful,
+#  but WITHOUT ANY WARRANTY; without even the implied warranty of
+#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#  GNU General Public License for more details.
+#
+#  A copy of the GNU General Public License is available at
+#  http://www.r-project.org/Licenses/
+#
 logtrans <- function(object, ...) UseMethod("logtrans")
 
 logtrans.default<-
@@ -61,9 +74,10 @@ function(object, ..., alpha = seq(0.5, 6, by = 0.25) - min(y),
 }
 
 logtrans.formula <-
-function(object, data = NULL, ...)
+function(object, data, ...)
 {
-  object <- aov(object, data = data, y = TRUE, qr = TRUE)
+  object <- if(missing(data)) aov(object,y = TRUE, qr = TRUE)
+  else aov(object, data = data, y = TRUE, qr = TRUE)
   invisible(NextMethod("logtrans"))
 }
 
